<!--
Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
SPDX-License-Identifier: MIT
-->

# zstarfile

[![builds.sr.ht status](https://builds.sr.ht/~gotmax23/zstarfile/commits/main.svg)](https://builds.sr.ht/~gotmax23/zstarfile/commits/main?)

[![copr build status][badge-copr]][link-copr] (gotmax23/zstarfile)

[![copr build status][badge-copr-dev]][link-copr-dev] (gotmax23/zstarfile-dev)

tarfile extension with additional compression algorithms and PEP 706 by default

## Links

- [zstarfile project hub](https://sr.ht/~gotmax23/zstarfile)
- [zstarfile git.sr.ht repo](https://git.sr.ht/~gotmax23/zstarfile)
- [zstarfile tracker](https://todo.sr.ht/~gotmax23/zstarfile)
- [zstarfile mailing list][archives] ([~gotmax/zstarfile@lists.sr.ht][mailto])

[archives]: https://lists.sr.ht/~gotmax23/zstarfile
[mailto]: mailto:~gotmax/zstarfile@lists.sr.ht

## Contributing

See [CONTRIBUTING.md](https://git.sr.ht/~gotmax23/zstarfile/tree/main/item/CONTRIBUTING.md).

## License

This repository is licensed under

    SPDX-License-Identifer: MIT

[badge-copr]: https://copr.fedorainfracloud.org/coprs/gotmax23/zstarfile/package/python-zstarfile/status_image/last_build.png
[link-copr]: https://copr.fedorainfracloud.org/coprs/gotmax23/zstarfile/
[badge-copr-dev]: https://copr.fedorainfracloud.org/coprs/gotmax23/zstarfile-dev/package/python-zstarfile/status_image/last_build.png
[link-copr-dev]: https://copr.fedorainfracloud.org/coprs/gotmax23/zstarfile-dev/
